Update of /cvsroot/fink/dists/10.2/unstable/main/finkinfo/languages
In directory usw-pr-cvs1:/tmp/cvs-serv16392

Added Files:
        pyfort-8.2-2.info pyfort-8.2-2.patch 
Log Message:
Patch to make g77 default compiler - added g77 dependency.


--- NEW FILE: pyfort-8.2-2.info ---
Package: pyfort
Version: 8.2
Revision: 2
Description: Python-Fortran connection tool
DescDetail: <<
Pyfort is a tool for creating extensions to the Python language with
Fortran routines. It supports F77-interfaced routines now, 
with plans for supporting more of F90 later.
<<
Source: mirror:sourceforge:pyfortran/Pyfort-%v.tar.gz    
Source-MD5: 13e7eb1cbcc20f27f6d291757f63f236 
Patch: %f.patch
Depends: python (>= 2.2.1-8), numeric, tcltk, g77 (>= 3.1-20020420-1)
SourceDirectory: Pyfort-%v
CompileScript: python setup.py build
InstallScript: python setup.py install --prefix=%i
 mkdir -p %i/share/doc/%n
 cp -R test testc demo %i/share/doc/%n
DescPort: patch to make g77 default compiler.
DocFiles: README Legal.htm
License: OSI-Approved
Homepage: http://pyfortran.sourceforge.net
Maintainer: Jeffrey Whitaker <[EMAIL PROTECTED]>

--- NEW FILE: pyfort-8.2-2.patch ---
--- Pyfort-8.2/fortran_compiler.py.orig Tue Sep 10 06:58:35 2002
+++ Pyfort-8.2/fortran_compiler.py      Tue Sep 10 06:59:15 2002
@@ -347,14 +347,14 @@
         self.typedict = typedict
     
     def executable_name (self):
-        return "fort77"
+        return "g77 -O3 -funroll-all-loops"
 
     def header(self):
         "Return a string containing anything needed to add to the header."
         text = \
 """
 /* 
     Built by PyFort for the fort77 (GNU Darwin) compiler.
 */
 """
         return text 



-------------------------------------------------------
@@ -347,14 +347,14 @@
 """
 /* 
-    Built by PyFort for the fort77 (GNU Darwin) compiler.
+    Built by PyFort for the g77 compiler.
 */
 """
This sf.net email is sponsored by: OSDN - Tired of that same old
cell phone?  Get a new here for FREE!
https://www.inphonic.com/r.asp?r=sourceforge1&refcode1=vs3390
_______________________________________________
Fink-commits mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/fink-commits

Reply via email to